wikimediaci_utils
=================

A collection of utility functions that are commonly used in tools that
assist with Wikimedia Continuous Integration.


License
-------
Copyright 2016-2020 Kunal Mehta under the GPL v3 or any later version.
